@@ -7,7 +7,9 @@ class Command(BaseCommand):
     """
     def handle(self, *args, **options):
         from django.contrib.auth.management import create_permissions
-        from django.db.models import get_apps
+        from django.db.models import get_apps, get_models
+
+        verbosity = int(options['verbosity'])
 
         for app in get_apps():
-           create_permissions(app, None, 2)
\ No newline at end of file
+            create_permissions(app, None, verbosity)
